@@ -38,6 +38,8 @@
 int
 main (int argc, char *argv[])
 {
+#if !defined (EEL_OMIT_SELF_CHECK)
+
 	eel_make_warnings_and_criticals_stop_in_debugger ();
 	
 
@@ -57,5 +59,7 @@ main (int argc, char *argv[])
 	gnome_vfs_shutdown ();
 	eel_debug_shut_down ();
 
+#endif /* !EEL_OMIT_SELF_CHECK */
+	
 	return EXIT_SUCCESS;
 }
