@@ -670,8 +670,8 @@ eel_enumeration_id_contains_name (const char *id,
 	g_return_val_if_fail (name[0] != '\0', FALSE);
 
 	entry = enumeration_table_lookup (id);
-	g_return_val_if_fail (entry != NULL, -1);
-	g_return_val_if_fail (entry->enumeration != NULL, -1);
+	g_return_val_if_fail (entry != NULL, FALSE);
+	g_return_val_if_fail (entry->enumeration != NULL, FALSE);
 
 	return eel_enumeration_contains_name (entry->enumeration, name);
 }
