@@ -543,7 +543,8 @@ set_uri_and_mime_type (EelMimeApplicationChooser *chooser,
 
 	/* first %s is filename, second %s is mime-type description */
 	emname = g_strdup_printf ("<i>%s</i>", name);
-	label = g_strdup_printf (_("Select an application to open %s and others of type \"%s\""), emname, chooser->details->mime_description);
+	label = g_strdup_printf (_("Select an application to open %s and other files of type \"%s\""),
+				 emname, chooser->details->mime_description);
 	g_free (emname);
 	
 	gtk_label_set_markup (GTK_LABEL (chooser->details->label), label);
